==> org.kikaineko.mock.plugin.kikainekoMocker_1.0.1.zip: org/kikaineko/mock/framework/TargetClass.java <==
/*
 * Created on 2005/02/19
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.kikaineko.mock.framework;

import java.lang.reflect.Modifier;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;

import org.kikaineko.mock.analysis.exception.UndefinedValueException;
import org.kikaineko.mock.util.ToStringer;

/**
 * bNΏۂƂȂNX\B
 * 
 * @author Masayuki Ioki
 */
public class TargetClass {
	// eNX̖OBeNX΁AnameƓlɂȂB
	private transient String superName;

	// NX̖O
	private transient String name;

	private transient Class superClass;

	private transient String pack;

	private transient String instanceName;

	// OTargetMethodAlreturn ̃^Cv
	private transient TargetMethodMgn methodList;

	// OqXg[̃V{iStringΐjŒlreturn̒lZbg
	// {ł΁A̒lSetArrayłKv͖
	// Ԗڂ̃qXg[ƂƂ擾قeXg₷
	// ƂÂ܂SetArrayp
	// Ƃ₱ˁEEE[Aς₱̂
	// SetArray SetArrayByIntɂƂύX
	private transient SetArrayByInt calledHistory;

	private transient Class[] usedConcreteClasses;

	private transient TargetHistory currentHistory;

	// ϐL[ɕslێ
	private transient Hashtable undefValuesOnMethod;

	// target̃\bhqXgL[ɕslێ
	private transient SetArray undefValuesPool;

	public void setUsedConcreteClasses(Class[] cs) {
		usedConcreteClasses = cs;
	}

	public Class[] getUsedConcreteClasses() {
		return usedConcreteClasses;
	}

	public TargetClass(String name, String in) {
		this.name = name;
		this.superName = name;
		this.instanceName = in;
		methodList = new TargetMethodMgn();
		calledHistory = new SetArrayByInt();
		currentHistory = TargetHistory.makeCurrentHistory();
		undefValuesOnMethod = new Hashtable();
		undefValuesPool = new SetArray();
	}
	
	protected void setInstanceName(String in){
		this.instanceName = in;
	}

	/**
	 * pbP[W擾B
	 * 
	 * @return
	 */
	public String getPack() {
		return pack;
	}

	/**
	 * 
	 * @param pack
	 */
	public String getPackForSorce() {
		// ftHgpbP[W
		if (getPack().equals("")) {
			return "";
		}
		return "package " + getPack() + ";";
	}

	public void setPack(String pack) {
		this.pack = pack;
	}

	public Class getSuperClass() {
		return superClass;
	}

	public void setSuperClass(Class c) {
		superClass = c;
		superName = superClass.getName();
	}

	public String getClassName() {
		return name;
	}

	public void setClassName(String name) {
		this.name = name;
	}

	public String getSuperName() {
		return superName;
	}

	public String getInstanceName() {
		return instanceName;
	}

	/**
	 * łnameo^Ă΁AsȂB
	 */
	protected void addMethod(String methodName, String retType) {
		methodList.add(methodName, retType);
	}

	/**
	 * \bhĂ΂ꂽƂL^
	 * 
	 * @param methodName
	 * @param retType
	 */
	public void invokingMethod(String retType, String methodName,
			Class[] argsClasses, Object[] args) {
		addMethod(methodName, retType);
		if (argsClasses != null){
			currentHistory.add(methodName, argsToStrings(argsClasses, args));
		}else{
			currentHistory.add(methodName, argsToStringsWithoutArgsClasses(args));
		}
	}

	private String[] argsToStrings(Class[] argsClasses, Object[] argsVaules){
		if (argsVaules != null) {
			String[] temps = new String[argsVaules.length];
			for (int i = 0; i < argsVaules.length; i++) {
				temps[i]=(ToStringer.getStrick(argsVaules[i],
						argsClasses[i]));
			}
			return temps;
		}else{
			return new String[0];
		}
	}

	// TODO
	/**
	 * ̃NX`null̏ꍇ ʏ킱̂悤ȌĂяo͂肦Ȃ͂ÃeXgł̂悤ȏȗIȌĂяoĂ邽
	 * bIɋBeXgCÃ\bh͍폜
	 * 
	 * @param argsVaules
	 * @return
	 * @deprecated
	 */
	// TODO
	// TODO
	private String[] argsToStringsWithoutArgsClasses(Object[] argsVaules) {
		if (argsVaules != null) {
			String[] temps = new String[argsVaules.length];
			for (int i = 0; i < argsVaules.length; i++) {
				temps[i]=(ToStringer.getStrick(argsVaules[i],
						null));
			}
			return temps;
		}else{
			return new String[0];
		}
	}

	public void overWriteHistory(int historySymbol, String re) {
		calledHistory.overWriteValue(historySymbol, re);
	}

	public void overWriteMethodReType(String name, String retType) {
		methodList.overWriteReturnType(name, retType);
	}

	/**
	 * ̃\bhԂB
	 * 
	 * @return
	 */
	public int howManyMethods() {
		return methodList.size();
	}

	/**
	 * iԖڂ̃\bhԂB
	 * 
	 * @param i
	 * @return
	 */
	public String getMethodName(int i) {
		return methodList.getName(i);
	}

	/**
	 * iԖڂ̃\bh̕Ԃl̃^CvԂB
	 * 
	 * @param i
	 * @return
	 */
	public String getReturnType(int i) {
		return methodList.getReturnType(i);
	}

	public void setMethodVisible(String name, String vis) {
		methodList.setVisibl(name, vis);
	}

	/**
	 * iԖڂ \bh̉Ԃ܂
	 * 
	 * @return
	 */
	public String getMethodVisible(int i) {
		return methodList.getVisible(i);
	}

	/**
	 * ̃qXg[ԂB
	 * 
	 * @return
	 */
	public int howManyHistories() {
		return calledHistory.size();
	}

	/**
	 * 
	 * @param i
	 * @return
	 */
	public String getHistoryAsStringWithoutUndestroyMethod(int i) {
		return getHistoryAt(i).toStringWithoutUndestroyMethod();
	}
	public String[] getHistoryAsStringArrayWithoutUndestroyMethod(int i) {
		return getHistoryAt(i).toArrayWithoutUndestroyMethod();
	}
	
	public String getHistoryAsStringArrayExpressionWithoutUndestroyMethod(int i) {
		return getHistoryAt(i).toStringArrayExpressionWithoutUndestroyMethod();
	}

	public String getHistoryAsRawString(int i) {
		return getHistoryAt(i).toString();
	}

	/**
	 * 
	 * @param index
	 * @return
	 */
	public TargetHistory getHistoryAt(int index) {
		int symbol = Integer.parseInt(calledHistory.getName(index));
		return TargetHistory.getTargetHistoryBySymbol(symbol);
	}

	/**
	 * iԖڂ̃qXg[̂ɕԂׂl
	 * 
	 * @param i
	 * @return
	 */
	public String getValueAtHistory(int i) {
		return calledHistory.getValueAt(i).toString();
	}

	/**
	 * @return
	 */
	public boolean hasSuperClass() {
		return !name.equals(superName);
	}

	public boolean hasMethodByName(String name) {
		return methodList.hasName(name);
	}

	public void addException(String methodName, String exception) {
		methodList.addException(methodName, exception);
	}

	/**
	 * iԖڂ̃\bh̗ÖꗗԂ
	 * 
	 * @param i
	 * @return
	 */
	public String[] getTargetMethodException(int i) {
		return methodList.getExceptions(i);
	}

	public boolean hasTargetMethodException(int i) {
		return methodList.hasException(i);
	}

	public int expectValueAtCurrentHistory(String re) {
		int symbol = currentHistory.getSymbolOfFreezedCurrentHistoryAndPoolIt();
		addHistory(symbol, re);
		return symbol;
	}

	protected void addHistory(int historySymbol, String re) {
		calledHistory.add(historySymbol, re);
	}

	public String getCurrentHistoryAsString() {
		return currentHistory.toString();
	}

	public boolean hasUndefValue() {
		return undefValuesPool.size() != 0;
	}

	public UndefinedValue[] getCurrentUndefValues() {
		UndefinedValue[] us = new UndefinedValue[undefValuesOnMethod.size()];
		int index = 0;
		for (Enumeration e = undefValuesOnMethod.elements(); e
				.hasMoreElements();) {
			us[index++] = (UndefinedValue) e.nextElement();
		}
		return us;
	}

	public UndefinedValue[] getUndefValues() {
		UndefinedValue[] us = new UndefinedValue[undefValuesPool.size()];
		for (int i = 0; i < us.length; i++) {
			us[i] = (UndefinedValue) undefValuesPool.getValue(i);
		}
		return us;
	}

	public Hashtable getRawUndefinedValues() {
		return undefValuesOnMethod;
	}

	public void checking() throws Exception {
		if (getSuperClass() != null
				&& Modifier.isFinal(getSuperClass().getModifiers())) {
			throw new UndefinedValueException(getInstanceName(),
					getSuperClass());
		}
	}

	/**
	 * ÃeXgIɌĂ΂
	 * 
	 */
	public void flush() {
		UndefinedValue[] uvs = getCurrentUndefValues();
		for (int i = 0; i < uvs.length; i++) {
			int nameSymbol = uvs[i]
					.getTargetClassHistorySymbolGeneratingThisUndefValue();
			String name = String.valueOf(nameSymbol);
			if (undefValuesPool.hasName(name)) {
				UndefinedValue uu = (UndefinedValue) undefValuesPool
						.getValue(name);
				uu.append(uvs[i]);
			} else {
				undefValuesPool.add(name, uvs[i]);
			}
		}
		undefValuesOnMethod = new Hashtable();
		currentHistory = TargetHistory.makeCurrentHistory();
	}

	/**
	 * iԖڂ̃\bhj󃁃\bhłKv邩ǂ𕷂
	 * 
	 * @param i
	 * @return
	 */
	public boolean isDestoryMethod(int i) {
		return methodList.isDestroyMethod(i);
	}

	public void mustBeDestoryMethodThis(int i) {
		methodList.mustBeDestroyMethod(i);
	}

	public String[] getHistoryTermsOnHistoryAt(int i) {
		return getHistoryAt(i).getHistoryTerms();
	}
	public Vector getHistoryTermsOnHistoryAtForInMemory(int i) {
		return getHistoryAt(i).getHistoryTermsForInMemory();
	}
}

==> org.kikaineko.mock.plugin.kikainekoMocker_1.0.3.zip: org/kikaineko/mock/framework/TargetClass.java <==
/*
 * Created on 2005/02/19
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.kikaineko.mock.framework;

import java.lang.reflect.Modifier;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;

import org.kikaineko.mock.analysis.exception.UndefinedValueException;
import org.kikaineko.mock.util.ToStringer;

/**
 * bNΏۂƂȂNX\B
 * 
 * @author Masayuki Ioki
 */
public class TargetClass {
	// eNX̖OBeNX΁AnameƓlɂȂB
	private transient String superName;

	// NX̖O
	private transient String name;

	private transient Class superClass;

	private transient String pack;

	private transient String instanceName;

	// OTargetMethodAlreturn ̃^Cv
	private transient TargetMethodMgn methodList;

	// OqXg[̃V{iStringΐjŒlreturn̒lZbg
	// {ł΁A̒lSetArrayłKv͖
	// Ԗڂ̃qXg[ƂƂ擾قeXg₷
	// ƂÂ܂SetArrayp
	// Ƃ₱ˁEEE[Aς₱̂
	// SetArray SetArrayByIntɂƂύX
	private transient SetArrayByInt calledHistory;

	private transient Class[] usedConcreteClasses;

	private transient TargetHistory currentHistory;

	// ϐL[ɕslێ
	private transient Hashtable undefValuesOnMethod;

	// target̃\bhqXgL[ɕslێ
	private transient SetArray undefValuesPool;

	public void setUsedConcreteClasses(Class[] cs) {
		usedConcreteClasses = cs;
	}

	public Class[] getUsedConcreteClasses() {
		return usedConcreteClasses;
	}

	public TargetClass(String name, String in) {
		this.name = name;
		this.superName = name;
		this.instanceName = in;
		methodList = new TargetMethodMgn();
		calledHistory = new SetArrayByInt();
		currentHistory = TargetHistory.makeCurrentHistory();
		undefValuesOnMethod = new Hashtable();
		undefValuesPool = new SetArray();
	}

	protected void setInstanceName(String in) {
		this.instanceName = in;
	}

	/**
	 * pbP[W擾B
	 * 
	 * @return
	 */
	public String getPack() {
		return pack;
	}

	/**
	 * 
	 * @param pack
	 */
	public String getPackForSorce() {
		// ftHgpbP[W
		if (getPack().equals("")) {
			return "";
		}
		return "package " + getPack() + ";";
	}

	public void setPack(String pack) {
		this.pack = pack;
	}

	public Class getSuperClass() {
		return superClass;
	}

	public void setSuperClass(Class c) {
		superClass = c;
		superName = superClass.getName();
	}

	public String getClassName() {
		return name;
	}

	public void setClassName(String name) {
		this.name = name;
	}

	public String getSuperName() {
		return superName;
	}

	public String getInstanceName() {
		return instanceName;
	}

	/**
	 * łnameo^Ă΁AsȂB
	 */
	protected void addMethod(String methodName, String retType) {
		methodList.add(methodName, retType);
	}

	/**
	 * \bhĂ΂ꂽƂL^
	 * 
	 * @param methodName
	 * @param retType
	 */
	public void invokingMethod(String retType, String methodName,
			Class[] argsClasses, Object[] args) {
		addMethod(methodName, retType);
		if (argsClasses != null) {
			currentHistory.add(methodName, argsToStrings(argsClasses, args));
		} else {
			currentHistory.add(methodName,
					argsToStringsWithoutArgsClasses(args));
		}
	}
	
	
	/**
	 * RXgN^Ă΂ꂽƂL^
	 * 
	 * @param methodName
	 * @param retType
	 */
	public void invokingConstrutor(String retType, String methodName,
			Class[] argsClasses, Object[] args) {
		if(currentHistory.length()!=0){
			currentHistory=TargetHistory.makeCurrentHistory();
		}
		invokingMethod(retType, methodName, argsClasses, args);
	}
	private String[] argsToStrings(Class[] argsClasses, Object[] argsVaules) {
		if (argsVaules != null) {
			String[] temps = new String[argsVaules.length];
			for (int i = 0; i < argsVaules.length; i++) {
				temps[i] = (ToStringer.getStrick(argsVaules[i], argsClasses[i]));
			}
			return temps;
		} else {
			return new String[0];
		}
	}

	// TODO
	/**
	 * ̃NX`null̏ꍇ ʏ킱̂悤ȌĂяo͂肦Ȃ͂ÃeXgł̂悤ȏȗIȌĂяoĂ邽
	 * bIɋBeXgCÃ\bh͍폜
	 * 
	 * @param argsVaules
	 * @return
	 * @deprecated
	 */
	// TODO
	// TODO
	private String[] argsToStringsWithoutArgsClasses(Object[] argsVaules) {
		if (argsVaules != null) {
			String[] temps = new String[argsVaules.length];
			for (int i = 0; i < argsVaules.length; i++) {
				temps[i] = (ToStringer.getStrick(argsVaules[i], null));
			}
			return temps;
		} else {
			return new String[0];
		}
	}

	public void overWriteHistory(int historySymbol, String re) {
		calledHistory.overWriteValue(historySymbol, re);
	}

	public void overWriteMethodReType(String name, String retType) {
		methodList.overWriteReturnType(name, retType);
	}

	/**
	 * ̃\bhԂB
	 * 
	 * @return
	 */
	public int howManyMethods() {
		return methodList.size();
	}

	/**
	 * iԖڂ̃\bhԂB
	 * 
	 * @param i
	 * @return
	 */
	public String getMethodName(int i) {
		return methodList.getName(i);
	}

	/**
	 * iԖڂ̃\bh̕Ԃl̃^CvԂB
	 * 
	 * @param i
	 * @return
	 */
	public String getReturnType(int i) {
		return methodList.getReturnType(i);
	}

	public void setMethodVisible(String name, String vis) {
		methodList.setVisibl(name, vis);
	}

	/**
	 * iԖڂ \bh̉Ԃ܂
	 * 
	 * @return
	 */
	public String getMethodVisible(int i) {
		return methodList.getVisible(i);
	}

	/**
	 * ̃qXg[ԂB
	 * 
	 * @return
	 */
	public int howManyHistories() {
		return calledHistory.size();
	}

	/**
	 * 
	 * @param i
	 * @return
	 */
	public String getHistoryAsStringWithoutUndestroyMethod(int i) {
		return getHistoryAt(i).toStringWithoutUndestroyMethod();
	}

	public String[] getHistoryAsStringArrayWithoutUndestroyMethod(int i) {
		return getHistoryAt(i).toArrayWithoutUndestroyMethod();
	}

	public String getHistoryAsStringArrayExpressionWithoutUndestroyMethod(int i) {
		return getHistoryAt(i).toStringArrayExpressionWithoutUndestroyMethod();
	}
	public String getSanitHistoryAsStringArrayExpressionWithoutUndestroyMethod(int i) {
		return getHistoryAsStringArrayExpressionWithoutUndestroyMethod(i).replaceAll("\\\\", "\\\\\\\\");
	}

	public String getHistoryAsRawString(int i) {
		return getHistoryAt(i).toString();
	}

	/**
	 * 
	 * @param index
	 * @return
	 */
	public TargetHistory getHistoryAt(int index) {
		int symbol = Integer.parseInt(calledHistory.getName(index));
		return TargetHistory.getTargetHistoryBySymbol(symbol);
	}

	/**
	 * iԖڂ̃qXg[̂ɕԂׂl
	 * 
	 * @param i
	 * @return
	 */
	public String getValueAtHistory(int i) {
		return calledHistory.getValueAt(i).toString();
	}
	public String getSanitValueAtHistory(int i) {
		return getValueAtHistory(i).replaceAll("\\\\", "\\\\\\\\");
	}
	/**
	 * @return
	 */
	public boolean hasSuperClass() {
		return !name.equals(superName);
	}

	public boolean hasMethodByName(String name) {
		return methodList.hasName(name);
	}

	public void addException(String methodName, String exception) {
		methodList.addException(methodName, exception);
	}

	/**
	 * iԖڂ̃\bh̗ÖꗗԂ
	 * 
	 * @param i
	 * @return
	 */
	public String[] getTargetMethodException(int i) {
		return methodList.getExceptions(i);
	}

	public boolean hasTargetMethodException(int i) {
		return methodList.hasException(i);
	}

	public int expectValueAtCurrentHistory(String re) {
		int symbol = currentHistory.getSymbolOfFreezedCurrentHistoryAndPoolIt();
		addHistory(symbol, re);
		return symbol;
	}

	protected void addHistory(int historySymbol, String re) {
		calledHistory.add(historySymbol, re);
	}

	public String getCurrentHistoryAsString() {
		return currentHistory.toString();
	}

	public boolean hasUndefValue() {
		return undefValuesPool.size() != 0;
	}

	public UndefinedValue[] getCurrentUndefValues() {
		UndefinedValue[] us = new UndefinedValue[undefValuesOnMethod.size()];
		int index = 0;
		for (Enumeration e = undefValuesOnMethod.elements(); e
				.hasMoreElements();) {
			us[index++] = (UndefinedValue) e.nextElement();
		}
		return us;
	}

	public UndefinedValue[] getUndefValues() {
		UndefinedValue[] us = new UndefinedValue[undefValuesPool.size()];
		for (int i = 0; i < us.length; i++) {
			us[i] = (UndefinedValue) undefValuesPool.getValue(i);
		}
		return us;
	}

	public Hashtable getRawUndefinedValues() {
		return undefValuesOnMethod;
	}

	public void putUndefValue(String name, UndefinedValue undefV) {
		if (undefValuesOnMethod.containsKey(name)) {
			UndefinedValue u = (UndefinedValue) undefValuesOnMethod.get(name);
			int no = u.getNo();
			undefValuesOnMethod.put(name, undefV);
			String s=no+"."+name;
			undefValuesOnMethod.put(s, u);
		}else{
			undefValuesOnMethod.put(name, undefV);
		}
	}

	public void checking() throws Exception {
		if (checkingLogick()) {
			throw new UndefinedValueException(getInstanceName(),
					getSuperClass());
		}
	}

	private boolean checkingLogick() {
		if (getSuperClass() == null || getSuperClass() == void.class) {
			try {
				Class c = Class.forName(getClassName());
				return Modifier.isFinal(c.getModifiers());
			} catch (ClassNotFoundException e) {
			}

		} else {
			return Modifier.isFinal(getSuperClass().getModifiers());
		}
		return false;
	}

	/**
	 * ÃeXgIɌĂ΂
	 * 
	 */
	public void flush() {
		UndefinedValue[] uvs = getCurrentUndefValues();
		for (int i = 0; i < uvs.length; i++) {
			//uvs[i]𐶐qXg[擾
			int nameSymbol = uvs[i]
					.getTargetClassHistorySymbolGeneratingThisUndefValue();
			String name = String.valueOf(nameSymbol);
			if (undefValuesPool.hasName(name)) {
				UndefinedValue uu = (UndefinedValue) undefValuesPool
						.getValue(name);
				uu.append(uvs[i]);
			} else {
				undefValuesPool.add(name, uvs[i]);
			}
		}
		undefValuesOnMethod = new Hashtable();
		currentHistory = TargetHistory.makeCurrentHistory();
	}

	/**
	 * iԖڂ̃\bhj󃁃\bhłKv邩ǂ𕷂
	 * 
	 * @param i
	 * @return
	 */
	public boolean isDestoryMethod(int i) {
		return methodList.isDestroyMethod(i);
	}

	public void mustBeDestoryMethodThis(int i) {
		methodList.mustBeDestroyMethod(i);
	}

	public String[] getHistoryTermsOnHistoryAt(int i) {
		return getHistoryAt(i).getHistoryTerms();
	}
	public String[] getSanitHistoryTermsOnHistoryAt(int i) {
		String[] ss=getHistoryTermsOnHistoryAt(i);
		for(int j=0;j<ss.length;j++){
			ss[j]=ss[j].replaceAll("\\\\", "\\\\\\\\");
		}
		return ss;
	}

	public Vector getHistoryTermsOnHistoryAtForInMemory(int i) {
		return getHistoryAt(i).getHistoryTermsForInMemory();
	}
}
